@@ -26,16 +26,9 @@
 #include <KLocalizedContext>
 #include <KLocalizedString>
 
-#include "formatter.h"
 #include "kweathersettings.h"
-#include "locationquerymodel.h"
-#include "temperaturechartdata.h"
 #include "version.h"
-#ifndef Q_OS_ANDROID
-#include "weatherbackground.h"
-#endif
 #include "weatherlocation.h"
-#include "weatherlocationlistmodel.h"
 
 class AbstractHourlyWeatherForecast;
 class AbstractDailyWeatherForecast;
@@ -77,14 +70,6 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-    qmlRegisterSingletonType("kweather", 1, 0, "AboutData", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
-        return engine->toScriptValue(KAboutData::applicationData());
-    });
-
-    qmlRegisterSingletonType<WeatherLocationListModel>("kweather", 1, 0, "WeatherLocationListModel", [](QQmlEngine *engine, QJSEngine *) -> QObject * {
-        return WeatherLocationListModel::inst();
-    });
-
     engine.rootContext()->setContextProperty(QStringLiteral("settingsModel"), KWeatherSettings::self());
 
     WeatherLocation *emptyWeatherLocation = new WeatherLocation();
@@ -94,22 +79,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #else
     engine.rootContext()->setContextProperty(QStringLiteral("KWEATHER_IS_ANDROID"), false);
 #endif
-    Formatter formatter;
-    qmlRegisterSingletonInstance<Formatter>("kweather", 1, 0, "Formatter", &formatter);
-
-    qmlRegisterType<TemperatureChartData>("kweather", 1, 0, "TemperatureChartData");
-    qmlRegisterType<LocationQueryModel>("kweather", 1, 0, "LocationQueryModel");
-    qmlRegisterType<WeatherLocation>("kweather", 1, 0, "WeatherLocation");
-#ifndef Q_OS_ANDROID
-    qmlRegisterType<WeatherBackgroundRenderer>("kweather", 1, 0, "WeatherBackground");
-#endif
-
-    qRegisterMetaType<KWeatherCore::HourlyWeatherForecast>();
-    qRegisterMetaType<KWeatherCore::DailyWeatherForecast>();
-    qRegisterMetaType<QList<WeatherLocation *>>();
 
     // load setup wizard if first launch
-    engine.load(QUrl(QStringLiteral("qrc:///qml/main.qml")));
+    engine.loadFromModule("org.kde.kweather", "Main");
 
     // required for X11
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.kweather")));
